@@ -208,7 +208,7 @@ def binance_get(api, p, type_, start_time, end_time = None, symbol = None, aggre
   client = Client(api, p)
   assert type_ in ['trade_history', 'futures_funding', 'futures_klines', 'wallet_history', 'spot_klines'], 'Wrong type_: trade_history, futures_funding, futures_klines, wallet_history available'
   if aggreg is not None:
-    assert aggreg in ['1h', '1m', '1d'], 'Wrong aggreg_: 1m, 1h available'
+    assert aggreg in ['1h', '1m', '1d','12h'], 'Wrong aggreg_: 1m, 1h available'
     dct_cvt = {'1m': Client.KLINE_INTERVAL_1MINUTE, '1h':Client.KLINE_INTERVAL_1HOUR, '1d':Client.KLINE_INTERVAL_1DAY, '12h':Client.KLINE_INTERVAL_12HOUR}
     aggreg = dct_cvt[aggreg]
 
